==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CalloutAnnotationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutAnnotationDescription } from "./CalloutAnnotationDescription";
/**
 * @hidden
 */
var CalloutAnnotationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalloutAnnotationDescriptionMetadata, _super);
    function CalloutAnnotationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutAnnotationDescriptionMetadata.b = function (a) {
        if (CalloutAnnotationDescriptionMetadata.a == null) {
            CalloutAnnotationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutAnnotationDescriptionMetadata.c(CalloutAnnotationDescriptionMetadata.a);
        }
        if (a.j(CalloutAnnotationDescriptionMetadata.a)) {
            return;
        }
        a.y(CalloutAnnotationDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutAnnotationDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
        a.item("Text", "String");
        a.item("KeyRef", "(w:Key,wf:Key)DataRef");
        a.item("ContentRef", "(w:Content,wf:Content)DataRef");
        a.item("Series", "ExportedType:Series");
        a.item("FormatLabelRef", "(w:FormatLabel,wf:FormatLabel)MethodRef");
        a.item("TextColor", "Brush");
        a.item("Background", "Brush");
        a.item("Outline", "Brush");
        a.item("LeaderBrush", "Brush");
        a.item("StrokeThickness", "Number:double");
        a.item("BackgroundPaddingLeft", "Number:double");
        a.item("BackgroundPaddingTop", "Number:double");
        a.item("BackgroundPaddingRight", "Number:double");
        a.item("BackgroundPaddingBottom", "Number:double");
        a.item("BackgroundCornerRadius", "Number:double");
    };
    CalloutAnnotationDescriptionMetadata.d = function (a) {
        CalloutAnnotationDescriptionMetadata.b(a);
        a.aa("CalloutAnnotation", function () { return new CalloutAnnotationDescription(); });
        a.z("CalloutAnnotation", CalloutAnnotationDescriptionMetadata.a);
    };
    CalloutAnnotationDescriptionMetadata.$t = markType(CalloutAnnotationDescriptionMetadata, 'CalloutAnnotationDescriptionMetadata');
    CalloutAnnotationDescriptionMetadata.a = null;
    return CalloutAnnotationDescriptionMetadata;
}(Base));
export { CalloutAnnotationDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/CalloutAnnotationDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { SeriesDescriptionMetadata } from "./SeriesDescriptionMetadata";
import { CalloutAnnotationDescription } from "./CalloutAnnotationDescription";
/**
 * @hidden
 */
var CalloutAnnotationDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CalloutAnnotationDescriptionMetadata, _super);
    function CalloutAnnotationDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CalloutAnnotationDescriptionMetadata.b = function (a) {
        if (CalloutAnnotationDescriptionMetadata.a == null) {
            CalloutAnnotationDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CalloutAnnotationDescriptionMetadata.c(CalloutAnnotationDescriptionMetadata.a);
        }
        if (a.k(CalloutAnnotationDescriptionMetadata.a)) {
            return;
        }
        a.aa(CalloutAnnotationDescriptionMetadata.a);
        SeriesDescriptionMetadata.d(a);
    };
    CalloutAnnotationDescriptionMetadata.c = function (a) {
        a.item("XValueRef", "(w:XValue,wf:XValue)DataRef");
        a.item("YValueRef", "(w:YValue,wf:YValue)DataRef");
        a.item("Text", "String");
        a.item("KeyRef", "(w:Key,wf:Key)DataRef");
        a.item("ContentRef", "(w:Content,wf:Content)DataRef");
        a.item("Series", "ExportedType:Series");
        a.item("FormatLabelRef", "(w:FormatLabel,wf:FormatLabel)MethodRef");
        a.item("TextColor", "Brush");
        a.item("Background", "Brush");
        a.item("Outline", "Brush");
        a.item("LeaderBrush", "Brush");
        a.item("StrokeThickness", "Number:double");
        a.item("BackgroundPaddingLeft", "Number:double");
        a.item("BackgroundPaddingTop", "Number:double");
        a.item("BackgroundPaddingRight", "Number:double");
        a.item("BackgroundPaddingBottom", "Number:double");
        a.item("BackgroundCornerRadius", "Number:double");
    };
    CalloutAnnotationDescriptionMetadata.d = function (a) {
        CalloutAnnotationDescriptionMetadata.b(a);
        a.ac("CalloutAnnotation", function () { return new CalloutAnnotationDescription(); });
        a.ab("CalloutAnnotation", CalloutAnnotationDescriptionMetadata.a);
    };
    CalloutAnnotationDescriptionMetadata.$t = markType(CalloutAnnotationDescriptionMetadata, 'CalloutAnnotationDescriptionMetadata');
    CalloutAnnotationDescriptionMetadata.a = null;
    return CalloutAnnotationDescriptionMetadata;
}(Base));
export { CalloutAnnotationDescriptionMetadata };
